require 'uu/os/rest/dto'
require 'uu/os/uesuri'


# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Artifact State Template.
    module ArtifactStateTemplate
      # @see ArtifactStateTemplate#get_attributes
      class ArtifactStateTemplateAttributes < UU::OS::REST::DTO

        # Name of the artifact state template.
        attr_accessor :name

        # Code of the artifact state template.
        attr_accessor :code

        # Description of the artifact state template.
        attr_accessor :description

        # URI of the artifact state template.
        attr_accessor :uri

        # Type of the artifact state template.
        # 
        # @see UU::OS::Artifact::ArtifactStateType
        attr_accessor :type

        # After an artifact is created from the related meta artifact, it will be set into the state
        # marked as the entry state. There is always just one artifact state template marked
        # as an entry state on every meta artifact.
        attr_accessor :entry_state

        # Creation time of the artifact state template.
        attr_accessor :creation_time

        # Modification time of the artifact state template.
        attr_accessor :modification_time

        # Version of the artifact state template.
        attr_accessor :version

        # URI of the artifact state template's icon.
        attr_accessor :icon_uri

        # Order of the artifact state template. All artifact state templates are suggested to the user
        # in this order when setting the artifact state to an artifact which is created according
        # to the related meta artifact.
        attr_accessor :order

        # True, if there is an activity template that enables setting of this artifact state template
        # to artifacts. It it does not exist, the artifact state template cannot be set to any artifacts.
        attr_accessor :activity_template_exists

        # URI of the entity type of the artifact state template.
        attr_accessor :entity_type_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def entry_state
          attributes[:entryState]
        end

        def entry_state=(val)
          attributes[:entryState] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def order
          attributes[:order]
        end

        def order=(val)
          attributes[:order] = val
        end

        def activity_template_exists
          attributes[:activityTemplateExists]
        end

        def activity_template_exists=(val)
          attributes[:activityTemplateExists] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end

  end
end
