require 'time'
require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    
      module Attachment

        class AttachmentAttributes < UU::OS::REST::DTO

          # Normalized UESURI of the attachment.
          attr_accessor :uri

          # Code of the attachment.
          attr_accessor :code

          # Name of the attachment.
          attr_accessor :name

          # Description of the attachment.
          attr_accessor :description

          # Specifies if the attachment is locked.
          attr_accessor :locked

          # When the attachment has been locked. Nil if it is unlocked.
          attr_accessor :lock_time

          # What role has locked the attachment. Nil if it is unlocked.
          attr_accessor :lock_role_uri

          # Who (which access role) has locked the attachment. Nil if it is unlocked.
          attr_accessor :lock_access_role_uri

          # UESURI of the entity type of the attachment.
          attr_accessor :entity_type_uri
          
          # Version of attachment (It is increased with every modification of attachment).
          attr_accessor :version
          
          #Version label of the attachment.
          attr_accessor :version_label
          
          #Creation time of the attachment.
          attr_accessor :creation_time
          
          #Modification time of the attachment.
          attr_accessor :modification_time
          
          #Creation stamp of the attachment.
          attr_accessor :creation_stamp
          
          #Modification stamp of the attachment.
          attr_accessor :modification_stamp
          
          # Name of the file contained in the attachment
          attr_accessor :file_name

          def modification_stamp
            attributes[:modification_stamp]
          end

          def modification_stamp=(val) 
            attributes[:modification_stamp] = val
          end

          def creation_stamp
            attributes[:creation_stamp]
          end

          def creation_stamp=(val) 
            attributes[:creation_stamp] = val
          end

          def modification_time 
            attributes[:modification_time]
          end

          def modification_time=(val) 
            if val.kind_of?String
              attributes[:modification_time] = Time.parse(val)
            else
              attributes[:modification_time] = val
            end
          end

          def creation_time 
            attributes[:creation_time]
          end

          def creation_time=(val) 
            if val.kind_of?String
              attributes[:creation_time] = Time.parse(val)
            else
              attributes[:creation_time] = val
            end
          end

          def version_label 
            attributes[:version_label]
          end

          def version_label=(val) 
            attributes[:version_label] = val
          end

          def uri 
            attributes[:uri]
          end

          def uri=(val) 
            if val
              attributes[:uri] = UU::OS::UESURI.new(val)
            else
              attributes[:uri] = nil
            end
          end

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def locked 
            attributes[:locked]
          end

          def locked=(val) 
            attributes[:locked] = val
          end

          def lock_time 
            attributes[:lockTime]
          end

          def lock_time=(val) 
            if val.kind_of?String
              attributes[:lockTime] = Time.parse(val)
            else
              attributes[:lockTime] = val
            end
          end

          def lock_role_uri 
            attributes[:lockRoleUri]
          end

          def lock_role_uri=(val) 
            if val
              attributes[:lockRoleUri] = UU::OS::UESURI.new(val)
            else
              attributes[:lockRoleUri] = nil
            end
          end

          def lock_access_role_uri 
            attributes[:lockAccessRoleUri]
          end

          def lock_access_role_uri=(val) 
            if val
              attributes[:lockAccessRoleUri] = UU::OS::UESURI.new(val)
            else
              attributes[:lockAccessRoleUri] = nil
            end
          end

          def entity_type_uri 
            attributes[:entityTypeUri]
          end

          def entity_type_uri=(val) 
            if val
              attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
            else
              attributes[:entityTypeUri] = nil
            end
          end
          
          # @deprecated Use {AttachmentAttributes#version} instead.
          def revision 
            attributes[:version]
          end
          
          # @deprecated Use {AttachmentAttributes#version} instead.
          def revision=(val) 
            attributes[:version] = val
          end
          
          def version 
            attributes[:version]
          end

          def version=(val) 
            attributes[:version] = val
          end
          
          def file_name 
            attributes[:file_name]
          end

          def file_name=(val) 
            attributes[:file_name] = val
          end

        end

      end
    end
end
