require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/os/property/property_type'

module UU
  module OS
    module PropertyTemplate
      class PropertyTemplateEntryAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the entry (property template or property template collection).
        attr_accessor :uri

        # Name of the entry (property template or property template collection).
        attr_accessor :name

        # Code of the entry (property template or property template collection). 
        attr_accessor :code

        # Description of the entry (property template or property template collection).
        attr_accessor :description

        # Type of the value of the entry (Date, Image, Text, etc.). 
        attr_accessor :value_type

        # Value for the entry that is property template. If the entry is property template collection, the value is nil.
        attr_accessor :value

        # UESURI of the entity type of the entry.
        attr_accessor :entity_type_uri
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def value_type
          attributes[:valueType]
        end

        def value_type=(val)
          attributes[:valueType] = val
        end

        def value
          if (
          value_type == UU::OS::Property::PropertyType::REFERENCE or
          value_type == UU::OS::Property::PropertyType::INTERTERRITORIAL_REFERENCE) and
          ! attributes[:value].nil?
            return UU::OS::UESURI.new(attributes[:value])
          end

          attributes[:value]
        end

        def value=(val)
          # Value is not transformed, because it is Object. Only chance to guess
          # proper value type is either from type or template_uri attributes. But
          # these attributes are not available on plain get_value command.
          # Therefore we are not transforming data here to maintain API consistency.
          # Caller has to know which type he expects and parse value manually.
          attributes[:value] = val
        end
        
        def entity_type_uri
         attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end
  end
end
